cmd/stress: flush out Usage doc

Provide more context when you run `stress -h` besides just the flags.

Change-Id: I9dbe7ba2b7178dd7a542d8c4c29bf79999a38234
Reviewed-on: https://go-review.googlesource.com/44810
Reviewed-by: Brad Fitzpatrick <bradfitz@golang.org>
diff --git a/cmd/stress/stress.go b/cmd/stress/stress.go
index 470d261..ee68917 100644
--- a/cmd/stress/stress.go
+++ b/cmd/stress/stress.go
@@ -4,14 +4,14 @@
 
 // +build !plan9
 
 // The stress utility is intended for catching of episodic failures.
 // It runs a given process in parallel in a loop and collects any failures.
 // Usage:
 // 	$ stress ./fmt.test -test.run=TestSometing -test.cpu=10
 // You can also specify a number of parallel processes with -p flag;
 // instruct the utility to not kill hanged processes for gdb attach;
 // or specify the failure output you are looking for (if you want to
 // ignore some other episodic failures).
 package main
 
 import (
@@ -34,6 +34,19 @@
 	flagIgnore  = flag.String("ignore", "", "ignore failure if output matches `regexp`")
 )
 
+func init() {
+	flag.Usage = func() {
+		os.Stderr.WriteString(`The stress utility is intended for catching sporadic failures.
+It runs a given process in parallel in a loop and collects any failures.
+Usage:
+
+	$ stress ./fmt.test -test.run=TestSometing -test.cpu=10
+
+`)
+		flag.PrintDefaults()
+	}
+}
+
 func main() {
 	flag.Parse()
 	if *flagP <= 0 || *flagTimeout <= 0 || len(flag.Args()) == 0 {
@@ -4,14 +4,14 @@
 // +build !plan9
 
-// The stress utility is intended for catching of episodic failures.
+// The stress utility is intended for catching sporadic failures.
 // It runs a given process in parallel in a loop and collects any failures.
 // Usage:
@@ -4,14 +4,14 @@
 // instruct the utility to not kill hanged processes for gdb attach;
 // or specify the failure output you are looking for (if you want to
-// ignore some other episodic failures).
+// ignore some other sporadic failures).
 package main
 